#[non_exhaustive]pub enum Request<'a> {
RequestConnector {
connector: WpDrmLeaseConnectorV1,
},
Submit {},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
RequestConnector
request a connector for this lease
Indicates that the client would like to lease the given connector. This is only used as a suggestion, the compositor may choose to include any resources in the lease it issues, or change the set of leased resources at any time. Compositors are however encouraged to include the requested connector and other resources necessary to drive the connected output in the lease.
Requesting a connector that was created from a different lease device than this lease request raises the wrong_device error. Requesting a connector twice will raise the duplicate_connector error.
Fields
connector: WpDrmLeaseConnectorV1Submit
submit the lease request
Submits the lease request and creates a new wp_drm_lease_v1 object. After calling submit the compositor will immediately destroy this object, issuing any more requests will cause a wl_display error. The compositor doesn’t make any guarantees about the events of the lease object, clients cannot expect an immediate response. Not requesting any connectors before submitting the lease request will raise the empty_lease error.
This is a destructor, once sent this object cannot be used any longer.